@@ -39,18 +39,6 @@ static ClutterActor *singinggame_display_freq;
 
 
 
-
-
-
-
-
-
-
-
-/*
-FIXME we should handle x-axis with duration + current place of playback track.
-Now we just keep count how many signals are cathed.
-*/
 static void on_pitch_detected(JammoRecordingTrack* track, gfloat frequency, gpointer user_data) {
 		g_return_if_fail(contour_cursor != NULL);
 		g_return_if_fail(contour_trace_area != NULL);
@@ -193,7 +181,8 @@ static gboolean animate_clipping (gpointer data){
 
 static void add_cross_after_animation(ClutterTimeline* t, gpointer view){
 	ClutterActor* cross;
-	cross=tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/cross_icon.png", NULL));
+	cross=tangle_button_new_with_background_actors(clutter_texture_new_from_file("/opt/jammo/cross_icon.png",NULL),
+       clutter_texture_new_from_file("/opt/jammo/cross_icon_pressed.png", NULL));
 	g_object_set(cross, "x", 719.0,  "y", 5.0, NULL);
 	g_signal_connect (cross, "clicked", G_CALLBACK (singinggame_cross_click),NULL);
 	clutter_container_add(CLUTTER_CONTAINER(view), cross, NULL);
@@ -541,10 +530,13 @@ void song_prepare_icon(jammo_song* song){
 	song->y_size = y_size;
 
 	ClutterActor* texture = clutter_texture_new_from_file(image_filename, NULL);
-	ClutterActor* songbutton = tangle_button_new_with_background_actor(texture);
+	ClutterActor* interactive_texture = clutter_texture_new_from_file(image_filename, NULL);
+	clutter_actor_set_opacity(interactive_texture, 40.0); //This could be fancier effect.
+	ClutterActor* songbutton = tangle_button_new_with_background_actors(texture,interactive_texture);
 	song->songbutton = songbutton;
+	g_free(image_filename);
 
-	g_signal_connect(songbutton, "clicked", G_CALLBACK (song_icon_clicked),song);
+	song->callback_handler_id = g_signal_connect(songbutton, "clicked", G_CALLBACK (song_icon_clicked),song);
 }
 
 
@@ -552,6 +544,7 @@ void song_prepare_icon(jammo_song* song){
 This is for song selection menu
 */
 GList* song_init_songs_from_disk(){
+	printf("loading songs from disk\n");
 	GList* songs = NULL;
 
 	//On easy mode, load only songs from 'easy' folder
@@ -604,6 +597,15 @@ GList* song_init_songs_from_disk(){
 			}
 		//Next folder
 		}
-
+	printf("loading from disk done\n");
 return songs;
 }
+
+
+void song_free(jammo_song* song, gpointer data) {
+	g_free(song->name_with_pack);
+	g_free(song->fullpath);
+	g_signal_handler_disconnect(song->songbutton, song->callback_handler_id);
+	clutter_actor_destroy(song->songbutton);
+	g_free(song);
+}
