@@ -74,7 +74,7 @@ static gboolean save_image_pressed(TangleButton *tanglebutton, gpointer data){
 
 
 	printf("Selected '%s'\n",filename);
-	composition_game_file_helper_save_composition((gchar*)filename, theme->bottom_track_view, theme->upper_track_view, theme->prefix_for_saving);
+	composition_game_file_helper_save_composition((gchar*)filename, theme->bottom_track_view, theme->upper_track_view, theme->name, theme->variation);
 	jammo_mentor_speak_with_callback(jammo_mentor_get_default(),"save_confirmed.spx",animate_icon_to_cupboard,tanglebutton);
 	return FALSE;
 }
@@ -364,7 +364,8 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	theme->only_playing_mode=only_listening;
 	theme->animation_timelines=NULL;
 	theme->play_button = play_button;
-
+	theme->name = name;
+	theme->variation = variation;
 
 	JammoSequencer* sequencer = jammo_sequencer_new();
 	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), theme);
@@ -559,11 +560,6 @@ if (use_two_tracks) y_offset=80;
 	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
 
 
-	theme->prefix_for_saving = g_strdup_printf("+%s+%d+%s",name,variation,chum_is_easy_game()? "e":"a");
-	//example: +fantasy+2+e
-	//printf("prefix is '%s'\n",prefix_for_saving);
-
-
 	return theme;
 }
 
