@@ -7,10 +7,11 @@ typedef struct _jammo_theme{
 	ClutterActor* save_menu_container;  /* All samples and tracks are in here*/
 	JammoTrackView* bottom_track_view;
 	JammoTrackView* upper_track_view; //this is not used in 'easy' mode
-	gchar* prefix_for_saving; //This will contain theme-name, -variation and easy/advanced-mode
 	GList* animation_timelines; /*This is container for animation timelines of samplebuttons*/
 	ClutterActor* play_button; /* This is needed when sequencer stops we want change between stop and play images*/
 	gboolean only_playing_mode; //When editing this is FALSE. When coming from cupboard, only listen is allowed
+	const gchar *name;
+	gint variation;
 } jammo_theme;
 
 
