@@ -45,6 +45,8 @@
 
 #include "slider_helper.h" //There are ranges for slider
 
+//We want disconnect this when leaving
+static gulong handler_for_sequencer_stop = 0;
 
 //For keyboard
 static int UPPER_OCTAVE=3;
@@ -316,8 +318,16 @@ void instrument_metronome_clicked (TangleAction *action, GObject *source, const
 
 
 static void end_jamming() {
-	jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
-	g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
+	if (recording)
+		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
+
+	if (ad_hoc_slider_track)
+		g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
+
+	jammo_sequencer_stop(ad_hoc_sequencer);
+	g_object_unref(ad_hoc_sequencer);
+
+	g_signal_handler_disconnect(static_sequencer, handler_for_sequencer_stop);
 
 	//hide instrument_view
 	ClutterActor* mainview;
@@ -500,7 +510,7 @@ b) instrument_gui_start(NULL,sequencer, TANGLE_WIDGET(track->track_view));
 void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* parameter_sequencer, TangleWidget* slider_container)
 {
 	static_sequencer = parameter_sequencer;
-	g_signal_connect(static_sequencer, "stopped", G_CALLBACK(instrument_gui_on_sequencer_stopped), NULL);
+	handler_for_sequencer_stop = g_signal_connect(static_sequencer, "stopped", G_CALLBACK(instrument_gui_on_sequencer_stopped), NULL);
 
 	ClutterActor* mainview;
 	mainview = jammo_get_actor_by_id("main-views-widget");
