@@ -20,6 +20,7 @@ View contains three part:
 #include "../../meam/jammo-slider-event.h"
 #include "../../meam/jammo-slider-track.h"
 #include "../../meam/jammo-backing-track.h"
+#include "../../meam/jammo-metronome-track.h"
 
 #include "../jammo.h"
 #include "../jammo-mentor.h"
@@ -29,10 +30,31 @@ View contains three part:
 
 #include "sequencer.h"
 #include "sequencer_loop.h"
-#include "sequencer_general.h"
 #include "sequencer_track_view.h"
 #include "startmenu.h"
 
+//Copy pasted from jammo-backing-track.c
+static gchar* str_replace(gchar* string, gsize position, gsize length, const gchar* replacement, gchar** replacement_end_return) {
+	gsize string_length;
+	gsize replacement_length;
+	gchar* s;
+	
+	string_length = strlen(string);
+	replacement_length = strlen(replacement);
+	s = (gchar*)g_malloc(string_length - length + replacement_length + 1);
+	g_memmove(s, string, position);
+	g_memmove(s + position, replacement, replacement_length);
+	g_memmove(s + position + replacement_length, string + position + length, string_length - position - length + 1);
+
+	if (replacement_end_return) {
+		*replacement_end_return = s + position + replacement_length;
+	}
+
+	g_free(string);
+
+	return s;
+}
+
 /*
 When sequencer starts: it calls load_state_from_file(load_only_backingtrack=TRUE)
  It starts loading backing-track.
@@ -41,6 +63,12 @@ When sequencer starts: it calls load_state_from_file(load_only_backingtrack=TRUE
   Then load_state_from_file(load_only_backingtrack=FALSE) loads another tracks.
 */
 
+//This is The sequencer of the game. All 'play'-buttons should play this.
+//All new tracks are added to this
+//If metronome is enabled it is added to this
+JammoSequencer* static_sequencer;
+
+
 static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer track);
 
 static void load_state_from_file(gchar* filename, gboolean load_only_backingtrack) {
@@ -70,28 +98,43 @@ g_assert_cmpint (JSON_NODE_TYPE (root), ==, JSON_NODE_OBJECT);
 object = json_node_get_object (root);
 g_assert (object != NULL);
 
-	gint tempo;
-	gint pitch;
+	gint tempo = 110; //'normal' tempo
+	gchar* pitch ="D";  //'normal' pitch
 
 
 	//gint slot;    //TODO: not used
 	//gint loop_id; //TODO: function missing
 
-	//META data: If we are loading backing_track, we do not have yet sequencer.
-
-if (!load_only_backingtrack){
+	//META data: Load these only once
+if (load_only_backingtrack){
 	//int
 	node = json_object_get_member (object, "tempo");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
 		tempo = json_node_get_int (node);
 		printf("tempo: '%d'\n",tempo);
 	}
-	//int
+	//string
 	node = json_object_get_member (object, "pitch");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
-		pitch = json_node_get_int (node);
-		printf("pitch: '%d'\n",pitch);
+		pitch = (gchar*)  json_node_get_string (node);
+		printf("pitch: '%s'\n",pitch);
 	}
+
+	jammo_sequencer_set_tempo(static_sequencer,tempo);
+	jammo_sequencer_set_pitch(static_sequencer,pitch);
+
+	//Correct GUI-elements:
+	gchar* name_of_tempo_button;
+	if (tempo==130) name_of_tempo_button="tempo-button1";
+	else if (tempo==110) name_of_tempo_button="tempo-button2";
+	else /*(tempo==90)*/ name_of_tempo_button="tempo-button3";
+	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id(name_of_tempo_button)),TRUE);
+
+	gchar* name_of_pitch_button;
+	if (pitch[0]=='G') name_of_pitch_button="pitch-button1";
+	else if (pitch[0]=='D') name_of_pitch_button="pitch-button2";
+	else /* (pitch[0]=='A')*/ name_of_pitch_button="pitch-button3";
+	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id(name_of_pitch_button)),TRUE);
 }
 
 
@@ -151,12 +194,37 @@ if (!load_only_backingtrack){
 						printf("backing_track_filename: '%s'\n",backing_track_filename);
 
 						track = JAMMO_TRACK(jammo_backing_track_new(backing_track_filename));
-
 						// Create other tracks after the duration of the backing track is known.
 						JammoSample* sample;
-						sample = jammo_sample_new_from_file(backing_track_filename);
-						g_signal_connect(sample, "notify::duration", G_CALLBACK(on_duration_notify), track);
+						printf("pitch '%s', tempo '%d'\n",pitch,tempo);
 
+						//This code is copy-pasted from jammo-backing-track.c:287
+						gchar* s;
+						gchar* filename_for_sample = s = g_strdup(backing_track_filename);
+						gchar* tempo_string;
+						while ((s = strchr(s, '$'))) {
+							switch (s[1]) {
+								case '$':
+									filename_for_sample = str_replace(filename_for_sample, s - filename_for_sample, 2, "$", &s);
+									break;
+								case 't':
+									tempo_string = g_strdup_printf("%u", tempo);
+									filename_for_sample = str_replace(filename_for_sample, s - filename_for_sample, 2, tempo_string, &s);
+									g_free(tempo_string);
+									break;
+								case 'p':
+									filename_for_sample = str_replace(filename_for_sample, s - filename_for_sample, 2, pitch, &s);
+									break;
+								default:
+									g_warning("Unexpected parameter in the backing track filename: '$%c', skipped.", s[1]);
+									s += 2;
+									break;
+							}
+						}
+						sample = jammo_sample_new_from_file(filename_for_sample);
+						g_free(filename_for_sample);
+						g_signal_connect(sample, "notify::duration", G_CALLBACK(on_duration_notify), track);
+	
 					}
 					printf("Ending looking for BackingTrack\n");
 
@@ -166,19 +234,42 @@ if (!load_only_backingtrack){
 			else {
 			//EDITING-TRACK
 			if(strncmp(track_type, "EditingTrack", 12) == 0) {
-				track_view=sequencer_track_view_add_with_type(EDITING_TRACK_VIEW,muted,-1);
-
+				gint e_track_type=-1;
 				gchar* editing_track_type="";
 				//string
 				sub_node = json_object_get_member (sub_object, "editing-track-type");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
 					editing_track_type =(gchar*)  json_node_get_string (sub_node);
 					printf("editing-track-type: '%s'\n",editing_track_type);
-
-					//TODO: depending type choose color
-					ClutterColor sample_color = { 255, 255, 0, 255 };
-					g_object_set(track_view, "sample-color", &sample_color, NULL);
 				}
+				ClutterColor sample_color =  { 0, 0, 0, 255 };
+				if (strncmp(editing_track_type,"Rhythm",6) == 0 ) {
+					e_track_type = RHYTHM_TRACK;
+					sample_color.red   = 255;
+					sample_color.green = 155;
+					sample_color.blue  = 0;
+				}
+				else if (strncmp(editing_track_type,"Melody",6) == 0 ) {
+					e_track_type = MELODY_TRACK;
+					sample_color.red   = 0;
+					sample_color.green = 0;
+					sample_color.blue  = 155;
+				}
+				else if (strncmp(editing_track_type,"Harmony",7) == 0 ) {
+					e_track_type = HARMONY_TRACK;
+					sample_color.red   = 200;
+					sample_color.green = 0;
+					sample_color.blue  = 0;
+				}
+				else if (strncmp(editing_track_type,"Effect",6) == 0 ) {
+					e_track_type = EFFECT_TRACK;
+					sample_color.red    = 0;
+					sample_color.green  = 155;
+					sample_color.blue   = 0;
+				}
+				track_view=sequencer_track_view_add_with_type(EDITING_TRACK_VIEW,muted,e_track_type);
+				g_object_set(track_view, "sample-color", &sample_color, NULL);
+
 
 				//Array
 				sub_node = json_object_get_member (sub_object, "samples");
@@ -325,13 +416,10 @@ gboolean sequencer_change_to_bottom_view (TangleActor *actor, gpointer data) {
 	return TRUE;
 }
 
-static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer backing_track) {
-	//This is The sequencer of the game. All 'play'-buttons should play this.
-	//All new tracks are added to this
-	//If metronome is enabled it is added to this
-	JammoSequencer* sequencer = jammo_sequencer_new ();
 
 
+static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer backing_track) {
+
 	JammoSample* sample;
 	sample = JAMMO_SAMPLE(object);
 
@@ -340,14 +428,19 @@ static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer back
 	duration = jammo_sample_get_duration(sample);
 	g_print("Duration: %" G_GUINT64_FORMAT "\n", duration);
 
+	gint tempo_factory = 4;
+	//We want operate whole time with guint64.
+	guint64 temp=60*tempo_factory;
+	guint64 one_second = 1000000000L;
+	guint64 big = temp * one_second;
+	guint64 duration_of_one_slot = big / jammo_sequencer_get_tempo(static_sequencer);
 
-	gint number_of_slots = 32 ; //TODO: now we know that backing track has 32 slots.
+	gint number_of_slots = duration/duration_of_one_slot;
+	printf("*number_of_slots in backing_track: %d\n",number_of_slots);
 	gfloat slot_width = 40.0;
 	gfloat height = 50.0;
 	//sequencer_track_view uses internally this just created area.
-	sequencer_track_view_create_area_for_tracks(JAMMO_SEQUENCER(sequencer),number_of_slots, duration, slot_width,height);
-
-	//tangle_widget_add(TANGLE_WIDGET(jammo_get_actor_by_id("fullsequencer-container_old_-for-tracks")), sequencer_view,NULL);
+	sequencer_track_view_create_area_for_tracks(static_sequencer,number_of_slots, duration, slot_width,height);
 
 
 	ClutterActor* track_view = NULL;
@@ -357,14 +450,23 @@ static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer back
 	load_state_from_file(inputFilename,FALSE);
 
 	// Do not call this function ever again!
-	g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_duration_notify), sequencer);
+	g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_duration_notify), static_sequencer);
 }
 
+JammoMetronomeTrack* static_metronome_track;
+
 /*
 This actor is visible when starting jammo_get_actor_by_id("fullsequencer-view");
 */
 void start_sequencer(gpointer filename)
 {
+	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	static_metronome_track = jammo_metronome_track_new();
+	jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(static_metronome_track));
+	jammo_metronome_track_set_time_signature_beats(static_metronome_track,4);
+	jammo_metronome_track_set_time_signature_note_value(static_metronome_track,4);
+	jammo_metronome_track_set_accent(static_metronome_track,FALSE);
+	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), TRUE);
 
 	printf("Starting sequencer GUI\n");
 	//inputFilename is global! (from sequencer.h)
@@ -380,14 +482,9 @@ void start_sequencer(gpointer filename)
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 
 
-	//Tune some things that can't be done with JSON only (TODO)
+	//Tune some things that can't be done with JSON only ("clamp-scrolling-offset-y")
 	sequencer_loop_tune_wheels();
 
-	//Default for tempo and and pitch
-	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("tempo-button2")),TRUE);
-	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("pitch-button2")),TRUE);
-
-
 	//Loading tracks from file:
 	if(inputFilename) {
 		FILE *ifp;
@@ -413,3 +510,52 @@ void leave_sequencer()
 }
 */
 
+
+
+/*
+ * CallBack for JSON
+ */
+void fullsequencer_general_arrow_clicked (TangleButton *tanglebutton, gpointer user_data){
+printf("up\n");
+sequencer_change_to_sequencer_view(NULL,NULL);
+}
+
+
+void fullsequencer_general_tempo_clicked(TangleButton *tanglebutton, gpointer user_data) {
+	printf("tempo clicked '%s'\n",clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)));
+
+	int new_tempo = 110;
+	if (strncmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)),"fast",4)==0)
+			new_tempo=130;
+	else if (strncmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)),"normal",6)==0)
+			new_tempo=110;
+	else if (strncmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)),"slow",4)==0)
+			new_tempo=90;
+	printf("new tempo:%d\n",new_tempo);
+	jammo_sequencer_set_tempo(static_sequencer, new_tempo);
+}
+
+
+void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer user_data) {
+	printf("pitch clicked '%s'\n",clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)));
+
+	gchar* new_pitch = "G";
+	if (strncmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)),"high",4)==0)
+			new_pitch = "G";
+	else if (strncmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)),"normal",6)==0)
+			new_pitch = "D";
+	else if (strncmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)),"low",3)==0)
+			new_pitch = "A";
+	printf("new pitch:'%s'\n",new_pitch);
+
+	jammo_sequencer_set_pitch(static_sequencer, new_pitch);
+}
+
+
+
+
+void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
+	printf("fullsequencer: Metronome pressed\n");
+
+	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), !tangle_button_get_selected(tanglebutton));
+}
