@@ -44,9 +44,6 @@ static gint tracks_in_use = 0;
 static JammoSequencer* sequencer; // for playing the tracks;
 
 
-static gboolean METRONOME_STATE = FALSE;
-
-
 static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
 static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
 static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data);
@@ -87,10 +84,10 @@ static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
 
 	gfloat x=0;
 	clutter_actor_set_position(label, x, 0.0);
-	x += 2 +  clutter_actor_get_width(label);
+	x += 1 +  clutter_actor_get_width(label);
 
 	clutter_actor_set_position(mute_button, x, 0.0);
-	x += 2.0 + clutter_actor_get_width(mute_button);
+	x += 1.0 + clutter_actor_get_width(mute_button);
 
 	clutter_actor_set_position(volume_button, x, 0.0);
 
@@ -168,11 +165,10 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 	//Choose label-image:
 	switch (track_view_type) {
 		case 	INSTRUMENT_TRACK_VIEW:
-			name_of_label_button = "/opt/jammo/sequencer/label_keyboard.png";
-			break;
-
-		case DRUM_TRACK_VIEW:
-			name_of_label_button = "/opt/jammo/sequencer/label_drum.png";
+			if (optional_parameter==1)
+				name_of_label_button = "/opt/jammo/sequencer/label_drum.png"; //drum has own label
+			else
+				name_of_label_button = "/opt/jammo/sequencer/label_keyboard.png";
 			break;
 
 		case SLIDER_TRACK_VIEW:
@@ -184,7 +180,16 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 			break;
 
 		case EDITING_TRACK_VIEW:
-			name_of_label_button = "/opt/jammo/sequencer/label_loop.png";
+			if (optional_parameter==RHYTHM_TRACK)
+				name_of_label_button = "/opt/jammo/sequencer/label_loop_rhythm.png";
+			else if (optional_parameter==HARMONY_TRACK)
+				name_of_label_button = "/opt/jammo/sequencer/label_loop_harmony.png";
+			else if (optional_parameter==MELODY_TRACK)
+				name_of_label_button = "/opt/jammo/sequencer/label_loop_melody.png";
+			else if (optional_parameter==EFFECT_TRACK)
+				name_of_label_button = "/opt/jammo/sequencer/label_loop_effect.png";
+			else //Same sane default value
+				name_of_label_button = "/opt/jammo/sequencer/label_loop_effect.png";
 			break;
 /*
 		case BACKING_TRACK_VIEW:
@@ -205,7 +210,6 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 	if (track_view_type == INSTRUMENT_TRACK_VIEW)
 		{
 		track = JAMMO_TRACK(jammo_instrument_track_new(optional_parameter));
-		jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(track),FALSE);
 
 		// TODO set transpose. Key of the song should be stored somewhere
 		instrument_gui_set_transpose('c');
@@ -223,7 +227,7 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 	else if (track_view_type == SLIDER_TRACK_VIEW)
 		{
 		track = JAMMO_TRACK(jammo_slider_track_new(optional_parameter));
-		jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(track),FALSE);
+
 
 		track_view_actor = tangle_widget_new();
 		g_object_set_data (G_OBJECT(track_view_actor),"track",track);
@@ -423,15 +427,13 @@ bool save_sequencer_state(gchar* outputFilename) {
 	return FALSE;
 }
 
+//JSON callback
+void fullsequencer_on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
+	//printf("fullsequencer_on_cursor_notify_x\n");
 
-static void on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
-	TangleVault* vault;
-	TangleScrollingActor* scrolling_actor;
-	JammoCursor* cursor;
+	TangleScrollingActor* scrolling_actor = TANGLE_SCROLLING_ACTOR(jammo_get_actor_by_id("fullsequencer-scroller-for-tracks"));
 	gfloat x, visible, offset, max;
 
-	vault = TANGLE_VAULT(user_data);
-	tangle_vault_get(vault, 2, TANGLE_TYPE_SCROLLING_ACTOR, &scrolling_actor, JAMMO_TYPE_CURSOR, &cursor);
 	g_object_get(object, "x", &x, NULL);
 	g_object_get(scrolling_actor, "width", &visible, "scrolling-offset-x", &offset, "scrolling-width", &max, NULL);
 	if (x < offset) {
@@ -478,23 +480,6 @@ void fullsequencer_record_clicked (TangleButton* tanglebutton, gpointer none){
 }
 
 
-//TODO. use metronome-track
-//is METRONOME_STATE used?
-void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
-	printf("fullsequencer: Metronome pressed\n");
-
-		//tanglebutton is toggle-button.
-	gboolean selected;
-	g_object_get(tanglebutton, "selected", &selected,  NULL);
-
-	if (selected) {
-		METRONOME_STATE = FALSE;
-	}
-	else {
-		METRONOME_STATE = TRUE;
-	}
-}
-
 
 void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Community pressed. Doesn't do anything\n");
@@ -503,6 +488,8 @@ void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none)
 void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Home pressed Doesn't do anything\n");
 
+	clutter_main_quit();
+
 	/*
 	jammo_sequencer_stop(sequencer);
 	save_sequencer_state();
@@ -543,35 +530,9 @@ void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_sl
 	//Height will be 0 and when track is added it will be raised
 	clutter_actor_set_size(scrolling_actor, 800-x_place_scroller, 0.0);
 
-
-
 	//CURSOR
-	ClutterActor* container_for_texture = tangle_widget_new();
-
-	ClutterActor* triangle_indicator = clutter_texture_new_from_file("/opt/jammo/sequencer/cursor_indicator.png", NULL);
-
-	tangle_widget_add(TANGLE_WIDGET(container_for_texture), triangle_indicator, NULL);
-	//clutter_actor_set_position(triangle_indicator,0,-48.0);
-	//Cursor:
-	ClutterColor color_for_texture = { 255, 255, 0, 128 };
+	texture_of_cursor = jammo_get_actor_by_id("fullsequencer_cursor_texture"); //We want change height of this
 	ClutterActor* cursor;
-
-	texture_of_cursor = clutter_rectangle_new_with_color(&color_for_texture); //this is static, because we want change it's height
-	clutter_actor_set_size(texture_of_cursor, 11.0, 0.0 );
-	clutter_actor_set_position(texture_of_cursor,8.0,48.0);
-
-	tangle_widget_add(TANGLE_WIDGET(container_for_texture), texture_of_cursor, NULL);
-
-	cursor = jammo_cursor_new(sequencer, container_for_texture);
-	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
-	clutter_actor_set_position(cursor, 0.0, 0.0);
-	clutter_actor_set_size(cursor, width_of_area, 80.0);
-	tangle_widget_add(TANGLE_WIDGET(track_container), cursor,NULL);
-
-	//For automatic scrolling on cursor movement
-	TangleVault* vault;
-
-	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
-	tangle_signal_connect_vault(texture_of_cursor, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
-
+	cursor = jammo_get_actor_by_id("fullsequencer_cursor");
+	clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
 }
