@@ -431,7 +431,7 @@ static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMento
 	} else {
 		localized_speech = g_strconcat(mentor->priv->language, "/", current_speech, NULL);
 	}
-	if ((filename = tangle_actor_lookup_filename(TANGLE_ACTOR(mentor), localized_speech))) {
+	if ((filename = tangle_lookup_filename(localized_speech))) {
 		mentor->priv->active_sample = jammo_sample_new_from_file(filename);
 		g_free(filename);
 	} else {
