@@ -483,21 +483,27 @@ gint gems_communication_sanitize_grouplist()
 	return TRUE;
 }
 
-gint gems_communication_process_connections()
+gint gems_communication_process_connecting()
 {
 	gems_components* data = gems_get_data();
 	if(data == NULL) return FALSE;
 	if(data->ph == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
-	// TODO after applying GObject to get the necessary data (gems_components) change to use g_list_foreach
 	// Check connecting list
 	data->communication->connecting = gems_service_jammo_process_list(data->communication->connecting, FALSE);
 	
-	// TODO data->communication->connections
-	
-	gems_communication_process_connected();
+	return TRUE;
+}
+
+gint gems_communication_process_rejected()
+{
+	gems_components* data = gems_get_data();
+	if(data == NULL) return FALSE;
+	if(data->ph == NULL) return FALSE;
+	if(data->communication == NULL) return FALSE;
 	
+	// Check rejected list
 	data->communication->rejected = gems_process_rejected(data->communication->rejected);
 	
 	return TRUE;
@@ -698,7 +704,7 @@ gint gems_communication_read_data(gint socket, void* data, gint length)
 	return read(socket, (gchar*)data, length);
 }
 
-void gems_communication_process_connected()
+gint gems_communication_process_connected()
 {
 	gems_components* data = gems_get_data();
 	gboolean cleanup_required = FALSE;
@@ -706,6 +712,11 @@ void gems_communication_process_connected()
 	GList* iterator = NULL;
 	gchar* logmsg = NULL;
 	gint bytesread = -1;
+	
+	if(data == NULL) return FALSE;
+	if(data->ph == NULL) return FALSE;
+	if(data->communication == NULL) return FALSE;
+	
 	iterator = g_list_first(data->communication->connections);
 	while(iterator)
 	{
@@ -908,6 +919,8 @@ void gems_communication_process_connected()
 		iterator = g_list_next(iterator);
 	}
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
+	
+	return TRUE;
 }
 
 gboolean gems_communication_process_data(gems_connection* element)
@@ -1486,4 +1499,32 @@ void gems_communication_peerhood_close_detected()
 	
 }
 
-
+gems_teacher_connection* gems_teacher_connection_init()
+{
+	gems_teacher_connection* tc = (gems_teacher_connection*)g_malloc(sizeof(gems_teacher_connection));
+	
+	tc->connection = NULL;
+	
+	return tc;
+}
+void gems_clear_teacher_connection()
+{
+	gems_components* data = gems_get_data();
+	
+	if(data == NULL) return;
+	if(data->teacher_connection == NULL) return;
+	if(data->teacher_connection->connection != NULL)
+	{
+		if(ph_c_connection_disconnect(data->teacher_connection->connection))
+		{
+			gchar* logmsg = g_strdup_printf("gems_clear_teacher_connection: connection to teacher was disconnected");
+			cem_add_to_log(logmsg,LOG_DEBUG);
+			g_free(logmsg);
+		}
+		ph_c_connection_delete(data->teacher_connection->connection);
+		data->teacher_connection->connection = NULL;
+	}
+	g_free(data->teacher_connection);
+	data->teacher_connection = NULL;
+	
+}
