@@ -64,6 +64,8 @@ enum
   PROP_CAN_ACTIVATE_PULL,
   PROP_RECORDING,
   PROP_EVENTLIST,
+  PROP_TEMPO_SCALE,
+  PROP_PITCH_SHIFT,
   PROP_LAST
 };
 
@@ -222,6 +224,14 @@ static void gst_jammo_sampler_class_init (GstJammoSamplerClass * klass)
   g_object_class_install_property (gobject_class, PROP_EVENTLIST,
       g_param_spec_pointer ("eventlist", "Get a list of events",
           "Get a list of events", G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gobject_class, PROP_TEMPO_SCALE,
+      g_param_spec_float ("tempo-scale", "Tempo scale", "Tempo scale factor of playback mode",
+      		0.0, 5.0, 1.0,
+          G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gobject_class, PROP_PITCH_SHIFT,
+      g_param_spec_int ("pitch-shift", "Pitch shift", "Pitch shift of produced sound",
+      		-12, 12, 0,
+          G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
   gstbasesrc_class->set_caps = GST_DEBUG_FUNCPTR (gst_jammo_sampler_setcaps);
   gstbasesrc_class->is_seekable =
       GST_DEBUG_FUNCPTR (gst_jammo_sampler_is_seekable);
@@ -336,6 +346,8 @@ static void gst_jammo_sampler_init (GstJammoSampler * src, GstJammoSamplerClass
 	src->last_event_processed=FALSE;
 
 	src->time=0;
+	src->pitch_shift=0;
+	src->tempo_scale=1.0;
 
   /* we operate in time */
   gst_base_src_set_format (GST_BASE_SRC (src), GST_FORMAT_TIME);
@@ -770,9 +782,9 @@ static void do_playback_process(GstJammoSampler * src){
 		}
 	timestamp = event->timestamp;
 
-	while (src->time > timestamp){
-		printf("DEBUG: gstjammosampler: delayed: %llu ms\n",(unsigned long long) (src->time - timestamp)/1000/1000);
-		int note=event->note;
+	while (src->time * src->tempo_scale > timestamp){
+		printf("DEBUG: gstjammosampler: delayed: %llu ms\n",(unsigned long long) ((src->time * src->tempo_scale - timestamp)/src->tempo_scale)/1000/1000);
+		int note=event->note + src->pitch_shift;
 
 		//note is unsigned.
 		//We can use sign to tell type of note. ON= +, OFF= -
@@ -1546,7 +1558,14 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 			printf("realtime\n");
 			GstClockTime timestamp;
 			timestamp = src->time;
+
 			event->timestamp=timestamp;
+			// when pitch shifting must make sure that note will not be less than zero
+			// note that pitch shifting only affects playback, not stored event
+			// stored events will be pitch shifted when played back
+			if (((gint)note)+ src->pitch_shift>=0) {
+				note+=src->pitch_shift;
+			}
 
 		if (event->type==JAMMOMIDI_NOTE_ON) {
 		/* It should be checked that note can be played, i.e. not all sampler
@@ -1625,6 +1644,12 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 				jammomidi_store_event_to_glist(&(src->eventlist), n->note, n->type, n->timestamp);
         }
       break;
+    case PROP_TEMPO_SCALE:
+      src->tempo_scale = g_value_get_float (value);
+      break;
+    case PROP_PITCH_SHIFT:
+      src->pitch_shift = g_value_get_int (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1675,6 +1700,12 @@ static void gst_jammo_sampler_get_property (GObject * object, guint prop_id,
 		case PROP_EVENTLIST:
 			g_value_set_pointer (value, src->eventlist);
 			break;
+		case PROP_TEMPO_SCALE:
+			g_value_set_float (value, src->tempo_scale);
+			break;
+		case PROP_PITCH_SHIFT:
+			g_value_set_int (value, src->pitch_shift);
+			break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
