@@ -27,9 +27,9 @@ enum {
 
 struct _JammoEditingTrackPrivate {
 	guint64 fixed_duration;
-	GstElement* bin;
 	GstElement* composition;
 	GList* samples;
+	guint tempo;
 };
 
 static void link_compatible_pads(GstElement* source_element, GstPad* source_pad, GstElement* sink_element);
@@ -167,9 +167,108 @@ static guint64 jammo_editing_track_get_duration(JammoTrack* track) {
 	return duration;
 }
 
-static GstElement* jammo_editing_track_get_playing_element(JammoPlayingTrack* playing_track) {
+static void jammo_editing_track_set_tempo(JammoTrack* track, guint tempo) {
+	JammoEditingTrack* editing_track;
+	GList* list;
+	JammoSample* sample;
+	GstElement* element;
+	guint64 start;
+	
+	editing_track = JAMMO_EDITING_TRACK(track);
+	
+	if (editing_track->priv->tempo != tempo) {
+		for (list = editing_track->priv->samples; list; list = list->next) {
+			sample = JAMMO_SAMPLE(list->data);
 
-	return JAMMO_EDITING_TRACK(playing_track)->priv->bin;
+			element = _jammo_sample_get_element(sample);
+			g_object_get(element, "start", &start, NULL);
+			start *= (gdouble)editing_track->priv->tempo / tempo;
+			g_object_set(element, "start", start, NULL);
+
+			jammo_sample_set_tempo(sample, tempo);
+		}
+	
+		editing_track->priv->tempo = tempo;
+	}
+}
+
+static void jammo_editing_track_set_pitch(JammoTrack* track, const gchar* pitch) {
+	JammoEditingTrack* editing_track;
+	GList* list;
+	
+	editing_track = JAMMO_EDITING_TRACK(track);
+	
+	for (list = editing_track->priv->samples; list; list = list->next) {
+		jammo_sample_set_pitch(JAMMO_SAMPLE(list->data), pitch);
+	}
+}
+
+static GstElement* jammo_editing_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
+	JammoEditingTrack* editing_track;
+	GstElement* source;
+	GstElement* element;
+	GstElement* convert;
+	gint64 duration;
+	
+	editing_track = JAMMO_EDITING_TRACK(playing_track);
+
+	/*
+	   +--gnlcomposition----------------+                            
+	   | +--gnlsource-------------+     |                            +-
+	   | | +--audiotestsrc--+     |     |     +--audioconvert--+     |
+	   | | | wave = 4       O =a> O =a> O =s> O                O =m> O
+	   | | +----------------+     |     |     +----------------+     |
+	   | +------------------------+     |                            +-
+	   +--------------------------------+                            
+	   
+	 =a> automatically: done by the gnl (behind the scenes)
+	 =g> ghostpad: created a ghostpad (gst_ghost_pad_new)
+	 =s> signalled: linked asyncronously ("pad-added" signal)
+	 =m> manually: linked syncronously (gst_element_link)
+	*/
+	
+	editing_track->priv->composition = gst_element_factory_make("gnlcomposition", NULL);
+	convert = gst_element_factory_make("audioconvert", NULL);
+	gst_bin_add_many(bin, editing_track->priv->composition, convert, NULL);
+	g_signal_connect(editing_track->priv->composition, "pad-added", G_CALLBACK(link_compatible_pads), convert);
+
+	source = gst_element_factory_make("gnlsource", NULL);
+	g_object_set(source,
+	             "priority", -1,
+		     "start", 0 * GST_SECOND,
+		     "duration", 1000 * GST_SECOND,
+		     "media-start", 0 * GST_SECOND,
+		     "media-duration", 1000 * GST_SECOND,
+	             NULL);
+	element = gst_element_factory_make("audiotestsrc", NULL);
+	g_object_set(element,
+	             "wave", 4, /* GST_AUDIO_TEST_SRC_WAVE_SILENCE */
+	             NULL);
+	gst_bin_add(GST_BIN(source), element);
+	gst_bin_add(GST_BIN(editing_track->priv->composition), source);
+	
+	if (editing_track->priv->fixed_duration != JAMMO_DURATION_INVALID) {
+		duration = editing_track->priv->fixed_duration;
+	} else {
+		duration = 0.1 * GST_SECOND;
+	}
+
+	source = gst_element_factory_make("gnlsource", NULL);
+	g_object_set(source,
+	             "priority", 1,
+		     "start", 0 * GST_SECOND,
+		     "duration", duration,
+		     "media-start", 0 * GST_SECOND,
+		     "media-duration", duration,
+	             NULL);
+	element = gst_element_factory_make("audiotestsrc", NULL);
+	g_object_set(element,
+	             "wave", 4, /* GST_AUDIO_TEST_SRC_WAVE_SILENCE */
+	             NULL);
+	gst_bin_add(GST_BIN(source), element);
+	gst_bin_add(GST_BIN(editing_track->priv->composition), source);
+
+	return convert;
 }
 
 static void jammo_editing_track_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -201,39 +300,6 @@ static void jammo_editing_track_get_property(GObject* object, guint prop_id, GVa
 		        break;
         }
 }
-
-static void jammo_editing_track_constructed(GObject* object) {
-	JammoEditingTrack* editing_track;
-	gint64 duration;
-	GstElement* source;
-	GstElement* element;
-	
-	editing_track = JAMMO_EDITING_TRACK(object);
-	
-	if (editing_track->priv->fixed_duration != JAMMO_DURATION_INVALID) {
-		duration = editing_track->priv->fixed_duration;
-	} else {
-		duration = 0.1 * GST_SECOND;
-	}
-
-	source = gst_element_factory_make("gnlsource", NULL);
-	g_object_set(source,
-	             "priority", 1,
-		     "start", 0 * GST_SECOND,
-		     "duration", duration,
-		     "media-start", 0 * GST_SECOND,
-		     "media-duration", duration,
-	             NULL);
-	element = gst_element_factory_make("audiotestsrc", NULL);
-	g_object_set(element,
-	             "wave", 4, /* GST_AUDIO_TEST_SRC_WAVE_SILENCE */
-	             NULL);
-	gst_bin_add(GST_BIN(source), element);
-	gst_bin_add(GST_BIN(editing_track->priv->composition), source);
-
-	G_OBJECT_CLASS(jammo_editing_track_parent_class)->constructed(object);
-}
-
 static void jammo_editing_track_finalize(GObject* object) {
 	G_OBJECT_CLASS(jammo_editing_track_parent_class)->finalize(object);
 }
@@ -256,8 +322,9 @@ static void jammo_editing_track_class_init(JammoEditingTrackClass* editing_track
 	JammoPlayingTrackClass* playing_track_class = JAMMO_PLAYING_TRACK_CLASS(editing_track_class);
 
 	track_class->get_duration = jammo_editing_track_get_duration;
-	playing_track_class->get_playing_element = jammo_editing_track_get_playing_element;
-	gobject_class->constructed = jammo_editing_track_constructed;
+	track_class->set_tempo = jammo_editing_track_set_tempo;
+	track_class->set_pitch = jammo_editing_track_set_pitch;
+	playing_track_class->setup_playing_element = jammo_editing_track_setup_playing_element;
 	gobject_class->finalize = jammo_editing_track_finalize;
 	gobject_class->dispose = jammo_editing_track_dispose;
 	gobject_class->set_property = jammo_editing_track_set_property;
@@ -300,59 +367,13 @@ static void jammo_editing_track_class_init(JammoEditingTrackClass* editing_track
 }
 
 static void jammo_editing_track_init(JammoEditingTrack* editing_track) {
-	GstElement* source;
-	GstElement* element;
-	GstElement* convert;
-	GstPad* pad;
-
 	editing_track->priv = G_TYPE_INSTANCE_GET_PRIVATE(editing_track, JAMMO_TYPE_EDITING_TRACK, JammoEditingTrackPrivate);
-	
-	/*
-	   +--bin----------------------------------------------------------+
-	   | +--gnlcomposition----------------+                            |
-	   | | +--gnlsource-------------+     |                            |
-	   | | | +--audiotestsrc--+     |     |     +--audioconvert--+     |
-	   | | | | wave = 4       O =a> O =a> O =s> O                O =g> O
-	   | | | +----------------+     |     |     +----------------+     |
-	   | | +------------------------+     |                            |
-	   | +--------------------------------+                            |
-	   +---------------------------------------------------------------+
-	   
-	 =a> automatically: done by the gnl (behind the scenes)
-	 =g> ghostpad: created a ghostpad (gst_ghost_pad_new)
-	 =s> signalled: linked asyncronously ("pad-added" signal)
-	 =m> manually: linked syncronously (gst_element_link)
-	*/
-	
-	editing_track->priv->bin = gst_bin_new(NULL);
-	editing_track->priv->composition = gst_element_factory_make("gnlcomposition", NULL);
-	convert = gst_element_factory_make("audioconvert", NULL);
-	gst_bin_add_many(GST_BIN(editing_track->priv->bin), editing_track->priv->composition, convert, NULL);
-	g_signal_connect(editing_track->priv->composition, "pad-added", G_CALLBACK(link_compatible_pads), convert);
-
-	pad = gst_element_get_pad(convert, "src");
-	gst_element_add_pad(editing_track->priv->bin, gst_ghost_pad_new("src", pad));
-	gst_object_unref(pad);
-
-	source = gst_element_factory_make("gnlsource", NULL);
-	g_object_set(source,
-	             "priority", -1,
-		     "start", 0 * GST_SECOND,
-		     "duration", 1000 * GST_SECOND,
-		     "media-start", 0 * GST_SECOND,
-		     "media-duration", 1000 * GST_SECOND,
-	             NULL);
-	element = gst_element_factory_make("audiotestsrc", NULL);
-	g_object_set(element,
-	             "wave", 4, /* GST_AUDIO_TEST_SRC_WAVE_SILENCE */
-	             NULL);
-	gst_bin_add(GST_BIN(source), element);
-	gst_bin_add(GST_BIN(editing_track->priv->composition), source);
+	editing_track->priv->tempo = 110;
 }
 
 static void link_compatible_pads(GstElement* source_element, GstPad* source_pad, GstElement* sink_element) {
 	GstPad* sink_pad;
-	
+
 	if (!(sink_pad = gst_element_get_compatible_pad(sink_element, source_pad, gst_pad_get_caps(source_pad)))) {
 		g_warning("No compatible pads found.\n");
 	} else {
