@@ -53,6 +53,15 @@ static void jammo_metronome_track_get_property(GObject* object, guint prop_id, G
 	}
 }
 
+static void jammo_metronome_track_set_tempo_uint(JammoTrack* track, guint tempo) {
+	jammo_metronome_track_set_tempo(JAMMO_METRONOME_TRACK(track), (gfloat)tempo);
+}
+
+static void jammo_metronome_track_set_pitch(JammoTrack* track, const gchar* pitch) {
+	// no need to do anything when pitch changes
+	;
+}
+
 static GstElement* jammo_metronome_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
 	JammoMetronomeTrack* metronome_track;
 
@@ -60,6 +69,8 @@ static GstElement* jammo_metronome_track_setup_playing_element(JammoPlayingTrack
 
 	metronome_track->priv->element = gst_element_factory_make("jammometronome", NULL);
 
+	gst_bin_add(bin, metronome_track->priv->element);
+
 	return metronome_track->priv->element;
 }
 
@@ -88,6 +99,8 @@ static void jammo_metronome_track_class_init(JammoMetronomeTrackClass* metronome
 	gobject_class->get_property = jammo_metronome_track_get_property;
 
 	track_class->get_duration = jammo_metronome_track_get_duration;
+	track_class->set_pitch = jammo_metronome_track_set_pitch;
+	track_class->set_tempo = jammo_metronome_track_set_tempo_uint;
 	playing_track_class->setup_playing_element = jammo_metronome_track_setup_playing_element;
 
 	g_type_class_add_private(gobject_class, sizeof(JammoMetronomeTrackPrivate));
