@@ -31,7 +31,10 @@ G_DEFINE_TYPE(JammoSequencer, jammo_sequencer, G_TYPE_OBJECT);
 
 enum {
 	PROP_0,
-	PROP_READY
+	PROP_READY,
+	PROP_TEMPO,
+	PROP_PITCH,
+	PROP_OUTPUT_FILENAME
 };
 
 enum {
@@ -42,16 +45,19 @@ enum {
 };
 
 struct _JammoSequencerPrivate {
+	guint tempo;
+	gchar* pitch;
+
 	GstElement* pipeline;
 	GstElement* adder;
-	GstElement* sink;
+	GstElement* audiosink;
 	GstElement* audioconvert;
 	GstElement* vorbisenc;
 	GstElement* oggmux;
 	GstElement* filesink;
 	GList* tracks;
 	guint64 duration;
-	gint mode;
+	gchar* output_filename;
 	
 	guint ready : 1;
 	guint playing : 1;
@@ -59,6 +65,9 @@ struct _JammoSequencerPrivate {
 
 static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data);
 static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer user_data);
+static GstElement* create_element(const gchar* name);
+static gboolean setup_audiosink(JammoSequencer* sequencer);
+static gboolean setup_filesink(JammoSequencer* sequencer, const gchar* filename);
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
@@ -93,6 +102,79 @@ gboolean jammo_sequencer_is_ready(JammoSequencer* sequencer) {
 	return sequencer->priv->ready;
 }
 
+/**
+ * jammo_sequencer_get_tempo:
+ * @sequencer: a #JammoSequencer
+ *
+ * Returns the tempo of the sequencer.
+ *
+ * Return value: tempo in bpm (beats per minute).
+ */
+guint jammo_sequencer_get_tempo(JammoSequencer* sequencer) {
+
+	return sequencer->priv->tempo;
+}
+
+/**
+ * jammo_sequencer_set_tempo:
+ * @sequencer: a #JammoSequencer
+ * @tempo: tempo in bpm (beats per minute)
+ *
+ * Sets the tempo of the sequencer.
+ */
+void jammo_sequencer_set_tempo(JammoSequencer* sequencer, guint tempo) {
+	GList* list;
+	JammoTrack* track;
+
+	if (sequencer->priv->tempo != tempo) {
+		sequencer->priv->tempo = tempo;
+		
+		for (list = sequencer->priv->tracks; list; list = list->next) {
+			track = JAMMO_TRACK(list->data);
+			JAMMO_TRACK_GET_CLASS(track)->set_tempo(track, tempo);
+		}
+		
+		g_object_notify(G_OBJECT(sequencer), "tempo");
+	}
+}
+
+/**
+ * jammo_sequencer_get_pitch:
+ * @sequencer: a #JammoSequencer
+ *
+ * Returns the pitch of the sequencer.
+ *
+ * Return value: pitch as a note (string).
+ */
+const gchar* jammo_sequencer_get_pitch(JammoSequencer* sequencer) {
+
+	return sequencer->priv->pitch;
+}
+
+/**
+ * jammo_sequencer_set_pitch:
+ * @sequencer: a #JammoSequencer
+ * @pitch: pitch as a note (string)
+ *
+ * Sets the pitch of the sequencer.
+ */
+void jammo_sequencer_set_pitch(JammoSequencer* sequencer, const gchar* pitch) {
+	GList* list;
+	JammoTrack* track;
+	
+	if (g_strcmp0(sequencer->priv->pitch, pitch)) {
+		g_free(sequencer->priv->pitch);
+		sequencer->priv->pitch = g_strdup(pitch);
+		
+		for (list = sequencer->priv->tracks; list; list = list->next) {
+			track = JAMMO_TRACK(list->data);
+			JAMMO_TRACK_GET_CLASS(track)->set_pitch(track, pitch);
+		}
+		
+		g_object_notify(G_OBJECT(sequencer), "pitch");
+	}
+}
+
 /**
  * jammo_sequencer_play:
  * @sequencer: a #JammoSequencer
@@ -182,17 +264,20 @@ JammoTrack* jammo_sequencer_get_track(JammoSequencer* sequencer, guint index) {
  */
 void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 	GstElement* element;
-	GstPad* pad;
 	
 	if (g_list_find(sequencer->priv->tracks, track)) {
 		g_warning("A track is already added into a sequencer.");
 	} else {
 		sequencer->priv->tracks = g_list_prepend(sequencer->priv->tracks, g_object_ref_sink(track));
-		element = _jammo_track_get_element(track);
+		_jammo_track_set_tempo(track, sequencer->priv->tempo);
+		_jammo_track_set_pitch(track, sequencer->priv->pitch);
+
+		element = gst_element_factory_make("audioconvert", NULL);
 		gst_bin_add(GST_BIN(sequencer->priv->pipeline), element);
-		if ((pad = gst_element_get_static_pad(element, "src"))) {
+		if (_jammo_track_setup_element(track, GST_BIN(sequencer->priv->pipeline), element)) {
 			gst_element_link(element, sequencer->priv->adder);
-			gst_object_unref(pad);
+		} else {
+			gst_bin_remove(GST_BIN(sequencer->priv->pipeline), element);
 		}
 
 		sequencer->priv->duration = 0;
@@ -273,154 +358,68 @@ gboolean jammo_sequencer_set_position(JammoSequencer* sequencer, guint64 positio
 }
 
 /**
- * jammo_sequencer_file_mode:
+ * jammo_sequencer_get_output_filename:
  * @sequencer: a #JammoSequencer
  *
- * Sets sequencer in file mode meaning that instead of playing it generates an ogg file.
+ * Gets the name of the output file if exists.
  *
- * Return value: int 0 success, 1 fail.
+ * Return value: The name of the output file (or NULL, if output is audible).
  */
-gint jammo_sequencer_file_mode(JammoSequencer* sequencer, gchar* filename) {
-	// no need to do anything if already in file mode
-	if (sequencer->priv->mode==SEQUENCER_FILE_MODE) {
-		return 0;
-	}
+const gchar* jammo_sequencer_get_output_filename(JammoSequencer* sequencer) {
 
-	// stop sequencer just in case
-	jammo_sequencer_stop(sequencer);
-
-	// switch ready to false
-	sequencer->priv->ready = FALSE;
-
-	// create wavenc and filesink
-	if (!(sequencer->priv->audioconvert = gst_element_factory_make("audioconvert", NULL))) {
-		g_warning("Could not create GStreamer element 'audioconvert'.\n");
-		return 1;
-	}	else if (!(sequencer->priv->vorbisenc = gst_element_factory_make("vorbisenc", NULL))) {
-		g_warning("Could not create GStreamer element 'vorbisenc'.\n");
-		return 1;
-	} else if (!(sequencer->priv->oggmux = gst_element_factory_make("oggmux", NULL))) {
-		g_warning("Could not create GStreamer element 'oggmux'.\n");
-		return 1;
-	} else if (!(sequencer->priv->filesink = gst_element_factory_make("filesink", NULL))) {
-		g_warning("Could not create GStreamer element 'filesink'.\n");
-		return 1;
-	}
-
-	// set quality to vorbisenc
-	g_object_set(G_OBJECT(sequencer->priv->vorbisenc), "quality", OGGQUALITY, NULL);
-
-	// set filename to filesink
-	g_object_set(G_OBJECT(sequencer->priv->filesink), "location", filename, NULL);
-
-	// unlink and remove audiosink
-	gst_element_unlink(sequencer->priv->adder, sequencer->priv->sink);
-	gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->sink);
-
-	// add audioconvert, vorbisenc, oggmux and filesink to bin
-	gst_bin_add_many(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
-
-	// link audioconvert, vorbisenc, oggmux and filesink
-	if (!gst_element_link(sequencer->priv->adder, sequencer->priv->audioconvert)) {
-		g_warning("linking adder and audioconvert failed");
-		return 1;
-	}
-	if (!gst_element_link(sequencer->priv->audioconvert, sequencer->priv->vorbisenc)) {
-		g_warning("linking audioconvert and vorbisenc failed");
-		return 1;
-	}
-	if (!gst_element_link(sequencer->priv->vorbisenc, sequencer->priv->oggmux)) {
-		g_warning("linking vorbisenc and oggmux failed");
-		return 1;
-	}
-	if (!gst_element_link(sequencer->priv->oggmux, sequencer->priv->filesink)) {
-		g_warning("linking oggmux and filesink failed");
-		return 1;
-	}
-
-	// set all instruments as not live & realtime
-	GList * list;
-	for (list = sequencer->priv->tracks; list; list = list->next) {
-		if(JAMMO_IS_INSTRUMENT_TRACK(list->data)) {
-			jammo_instrument_track_set_live(JAMMO_INSTRUMENT_TRACK(list->data), FALSE);
-			jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(list->data), FALSE);
-		}
-	}
-
-	sequencer->priv->mode=SEQUENCER_FILE_MODE;
-
-	// switch ready to true
-	sequencer->priv->ready = TRUE;
-
-	return 0;
+	return sequencer->priv->output_filename;
 }
 
 /**
- * jammo_sequencer_audio_mode:
+ * jammo_sequencer_set_output_filename:
  * @sequencer: a #JammoSequencer
+ * @output_filename: the name of the output audio file
  *
- * Sets sequencer back in audio mode meaning that instead of generating
- * a wav file it plays audio
+ * Sets sequencer to output a file (@output_filename is non-null), or normal audio via sound card
+ * (output_filename is null).
  *
- * Return value: int 0 success, 1 fail.
+ * Return value: Whether the operation succeeded.
  */
-gint jammo_sequencer_audio_mode(JammoSequencer* sequencer) {
-	// no need to do anything if already in audio mode
-	if (sequencer->priv->mode==SEQUENCER_AUDIO_MODE) {
-		return 0;
-	}
-
-	// stop sequencer just in case
-	jammo_sequencer_stop(sequencer);
-
-	// switch ready to false
-	sequencer->priv->ready = FALSE;
-
-	// create sink
-	if (!(sequencer->priv->sink = gst_element_factory_make("autoaudiosink", NULL))) {
-		g_warning("Could not create GStreamer element 'wavenc'.\n");
-		return 1;
-	}
-
-	// unlink, audioconvert, vorbisenc, oggmux and filesink
-	gst_element_unlink(sequencer->priv->adder, sequencer->priv->audioconvert);
-	gst_element_unlink(sequencer->priv->audioconvert, sequencer->priv->vorbisenc);
-	gst_element_unlink(sequencer->priv->vorbisenc, sequencer->priv->oggmux);
-	gst_element_unlink(sequencer->priv->oggmux, sequencer->priv->filesink);
-
-	// remove audioconvert, vorbisenc, oggmux and filesink from bin
-	gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audioconvert);
-	gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->vorbisenc);
-	gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->oggmux);
-	gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->filesink);
-
-	// add sink to bin
-	if (!gst_bin_add(GST_BIN(sequencer->priv->pipeline), sequencer->priv->sink)) {
-		g_warning("linking sink failed\n");
-		return 1;
-	}
-
-	// link sink
-	if (!gst_element_link(sequencer->priv->adder, sequencer->priv->sink)) {
-		g_warning("linking sink failed\n");
-		return 1;
-	}
-
+gboolean jammo_sequencer_set_output_filename(JammoSequencer* sequencer, const gchar* output_filename) {
+	gboolean retvalue = TRUE;
 	GList * list;
-	// set all instruments as live and realtime
-	for (list = sequencer->priv->tracks; list; list = list->next) {
-		if(JAMMO_IS_INSTRUMENT_TRACK(list->data)) {
-			jammo_instrument_track_set_live(JAMMO_INSTRUMENT_TRACK(list->data), TRUE);
-			jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(list->data), TRUE);
+	JammoTrack* track;
+	
+	if (g_strcmp0(sequencer->priv->output_filename, output_filename)) {
+		jammo_sequencer_stop(sequencer);
+	
+		if (output_filename && sequencer->priv->filesink) {
+			g_object_set(sequencer->priv->filesink, "location", output_filename, NULL);
+		} else {
+			/* Destroy current sinks. */
+			if (sequencer->priv->audiosink) {
+				gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audiosink);
+				sequencer->priv->audiosink = NULL;
+			}
+			if (sequencer->priv->filesink) {
+				gst_bin_remove_many(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
+				sequencer->priv->filesink = NULL;
+			}
+
+			/* Create a new sink. */
+			if (output_filename) {
+				retvalue = setup_filesink(sequencer, output_filename);
+			} else {
+				retvalue = setup_audiosink(sequencer);
+			}
+
+			for (list = sequencer->priv->tracks; list; list = list->next) {
+				track = JAMMO_TRACK(list->data);
+				_jammo_track_set_offline(track, output_filename != NULL);
+			}	
 		}
+		
+		g_free(sequencer->priv->output_filename);
+		sequencer->priv->output_filename = g_strdup(output_filename);
+		g_object_notify(G_OBJECT(sequencer), "output-filename");
 	}
-
-	sequencer->priv->mode=SEQUENCER_AUDIO_MODE;
-
-	// switch ready to true
-	sequencer->priv->ready = TRUE;
-
-	return 0;
+	
+	return retvalue;
 }
 
 static void jammo_sequencer_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -429,6 +428,15 @@ static void jammo_sequencer_set_property(GObject* object, guint prop_id, const G
 	sequencer = JAMMO_SEQUENCER(object);
 
 	switch (prop_id) {
+		case PROP_TEMPO:
+			jammo_sequencer_set_tempo(sequencer, g_value_get_uint(value));
+			break;
+		case PROP_PITCH:
+			jammo_sequencer_set_pitch(sequencer, g_value_get_string(value));
+			break;
+		case PROP_OUTPUT_FILENAME:
+			jammo_sequencer_set_output_filename(sequencer, g_value_get_string(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -444,6 +452,15 @@ static void jammo_sequencer_get_property(GObject* object, guint prop_id, GValue*
 		case PROP_READY:
 			g_value_set_boolean(value, sequencer->priv->ready);
 			break;
+		case PROP_TEMPO:
+			g_value_set_uint(value, sequencer->priv->tempo);
+			break;
+		case PROP_PITCH:
+			g_value_set_string(value, sequencer->priv->pitch);
+			break;
+		case PROP_OUTPUT_FILENAME:
+			g_value_set_string(value, sequencer->priv->output_filename);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -451,6 +468,12 @@ static void jammo_sequencer_get_property(GObject* object, guint prop_id, GValue*
 }
 
 static void jammo_sequencer_finalize(GObject* object) {
+	JammoSequencer* sequencer;
+
+	sequencer = JAMMO_SEQUENCER(object);
+
+	g_free(sequencer->priv->pitch);
+
 	G_OBJECT_CLASS(jammo_sequencer_parent_class)->finalize(object);
 }
 
@@ -458,9 +481,12 @@ static void jammo_sequencer_dispose(GObject* object) {
 	JammoSequencer* sequencer;
 
 	sequencer = JAMMO_SEQUENCER(object);
-	
-	g_object_unref(sequencer->priv->pipeline);
-	
+
+	if (sequencer->priv->pipeline) {
+		g_object_unref(sequencer->priv->pipeline);
+		sequencer->priv->pipeline=NULL;
+	}
+
 	g_list_foreach(sequencer->priv->tracks, (GFunc)g_object_unref, NULL);
 	g_list_free(sequencer->priv->tracks);
 	sequencer->priv->tracks = NULL;
@@ -487,6 +513,41 @@ static void jammo_sequencer_class_init(JammoSequencerClass* klass) {
 	                                "Whether the sequencer is ready to play or not",
 	                                TRUE,
 	                                G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSequencer:tempo:
+	 *
+	 * The tempo in beats per minute for all tracks in this sequencer.
+	 */
+	g_object_class_install_property(gobject_class, PROP_TEMPO,
+	                                g_param_spec_uint("tempo",
+	                                "Tempo",
+	                                "The tempo in beats per minute for all tracks in this sequencer",
+	                                0, G_MAXUINT, 110,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSequencer:pitch:
+	 *
+	 * The pitch as a note for all tracks in this sequencer.
+	 */
+	g_object_class_install_property(gobject_class, PROP_PITCH,
+	                                g_param_spec_string("pitch",
+	                                "Pitch",
+	                                "The pitch as a note for all tracks in this sequencer",
+	                                NULL,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSequencer:output-filename:
+	 *
+	 * The name of the audio file that is created as an output of this sequencer. If NULL, the audio is outputted into
+	 * a sound card (normal behaviour).
+	 */
+	g_object_class_install_property(gobject_class, PROP_OUTPUT_FILENAME,
+	                                g_param_spec_string("output-filename",
+	                                "Output filename",
+	                                "The name of the audio file that is created as an output of this sequencer",
+	                                NULL,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+
 	/**
 	 * JammoSequencer::started:
 	 * @sequencer: the object which received the signal
@@ -530,21 +591,17 @@ static void jammo_sequencer_init(JammoSequencer* sequencer) {
 	sequencer->priv = G_TYPE_INSTANCE_GET_PRIVATE(sequencer, JAMMO_TYPE_SEQUENCER, JammoSequencerPrivate);
 
 	sequencer->priv->ready = TRUE;
+	sequencer->priv->tempo = 110;
 
 	sequencer->priv->pipeline = jammo_pipeline_new(NULL);
 	bus = gst_pipeline_get_bus(GST_PIPELINE(sequencer->priv->pipeline));
 	gst_bus_add_watch(bus, on_bus_message, sequencer);
 	gst_object_unref (bus);
 
-	if (!(sequencer->priv->adder = gst_element_factory_make("adder", NULL))) {
-		g_warning("Could not create GStreamer element 'adder'.\n");
-	} else if (!(sequencer->priv->sink = gst_element_factory_make("autoaudiosink", NULL))) {
-		g_warning("Could not create GStreamer element 'autoaudiosink'.\n");
-	} else {
-		gst_bin_add_many(GST_BIN(sequencer->priv->pipeline), sequencer->priv->adder, /*sequencer->priv->volume,*/ sequencer->priv->sink, NULL);
-		gst_element_link(sequencer->priv->adder, sequencer->priv->sink);
+	if ((sequencer->priv->adder = create_element("adder"))) {
+		gst_bin_add(GST_BIN(sequencer->priv->pipeline), sequencer->priv->adder);
+		setup_audiosink(sequencer);
 	}
-	sequencer->priv->mode=SEQUENCER_AUDIO_MODE;
 }
 
 static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data) {
@@ -554,7 +611,6 @@ static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data)
 	GstObject* source;
 	GList* list;
 	JammoTrack* track;
-	GstObject* object;
 	
 	sequencer = JAMMO_SEQUENCER(data);
 	switch (GST_MESSAGE_TYPE(message)) {
@@ -572,9 +628,7 @@ static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data)
 			source = GST_MESSAGE_SRC(message);
 			for (list = sequencer->priv->tracks; list; list = list->next) {
 				track = JAMMO_TRACK(list->data);
-				object = GST_OBJECT(_jammo_track_get_element(track));
-				if (object == source || gst_object_has_ancestor(source, object)) {
-					_jammo_track_receive_message(track, message);
+				if (_jammo_track_receive_message(track, message)) {
 					break;
 				}
 			}
@@ -626,3 +680,49 @@ static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer
 		}	
 	}
 }
+
+static GstElement* create_element(const gchar* name) {
+	GstElement* element;
+
+	if (!(element = gst_element_factory_make(name, NULL))) {
+		g_critical("Could not create GStreamer element '%s'.", name);
+	}
+	
+	return element;
+}
+
+static gboolean setup_audiosink(JammoSequencer* sequencer) {
+	gboolean retvalue = FALSE;
+	
+	if ((sequencer->priv->audiosink = create_element("autoaudiosink"))) {
+		gst_bin_add(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audiosink);
+		if (!gst_element_link(sequencer->priv->adder, sequencer->priv->audiosink)) {
+			g_critical("Failed to link audiosink.");
+		} else {
+			retvalue = TRUE;
+		}
+	}
+	
+	return retvalue;
+}
+
+static gboolean setup_filesink(JammoSequencer* sequencer, const gchar* filename) {
+	gboolean retvalue = FALSE;
+	
+	if ((sequencer->priv->audioconvert = create_element("audioconvert")) &&
+	    (sequencer->priv->vorbisenc = create_element("vorbisenc")) &&
+	    (sequencer->priv->oggmux = create_element("oggmux")) &&
+	    (sequencer->priv->filesink = create_element("filesink"))) {
+		g_object_set(G_OBJECT(sequencer->priv->vorbisenc), "quality", OGGQUALITY, NULL);
+		g_object_set(G_OBJECT(sequencer->priv->filesink), "location", filename, NULL);
+
+		gst_bin_add_many(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
+		if (!gst_element_link_many(sequencer->priv->adder, sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL)) {
+			g_critical("Failed to link filesink.");
+		} else {
+			retvalue = TRUE;
+		}
+	}
+
+	return retvalue;
+}
