@@ -35,7 +35,7 @@ gint jammo_slider_event_glist_to_file(GList * list, char * filename) {
 			type='-';
 		else
 			type='m';
-		fprintf(fp, "%f%c %llu\n", frequency, type,(unsigned long long)((JammoSliderEvent*)(temp->data))->timestamp);
+		fprintf(fp, "%f%c %" G_GUINT64_FORMAT "\n", frequency, type,(unsigned long long)((JammoSliderEvent*)(temp->data))->timestamp);
 	}
 	fclose(fp);
 
@@ -67,7 +67,7 @@ GList * jammo_slider_event_file_to_glist(char * filename) {
 	char type;
 
 	//note can be one character "c" or two characters "c#"
-	while(fscanf(fp, "%f%c %llu", &frequency, &type, &time) != EOF) {
+	while(fscanf(fp, "%f%c %" G_GUINT64_FORMAT "", &frequency, &type, &time) != EOF) {
 
 		JammoSliderEvent * event;
 		event=malloc(sizeof(JammoSliderEvent));
@@ -82,7 +82,7 @@ GList * jammo_slider_event_file_to_glist(char * filename) {
 			event->type=JAMMO_SLIDER_EVENT_MOTION;
 		event->timestamp=time;
 
-		printf("Event from file:'%f' state'%d' time'%llu'\n", event->freq, event->type, (unsigned long long)event->timestamp);
+		printf("Event from file:'%f' state'%d' time'%" G_GUINT64_FORMAT " '\n", event->freq, event->type, (unsigned long long)event->timestamp);
 		list = g_list_prepend(list, event);
 	}
 	list = g_list_reverse(list);
