@@ -60,23 +60,23 @@ guint64 jammo_track_get_duration(JammoTrack* track) {
 }
 
 /**
- * _jammo_track_get_element:
+ * _jammo_track_setup_element:
  * @track: a #JammoTrack
+ * @bin: a #GstBin of where elements must be added
+ * @sink_element: a #GstElement to which a source element must be linked
  *
  * Internally used by a #JammoSequencer.
- *
- * Return value: a #GstElement of this track.
  */
-GstElement* _jammo_track_get_element(JammoTrack* track) {
-	GstElement* element = NULL;
+gboolean _jammo_track_setup_element(JammoTrack* track, GstBin* bin, GstElement* sink_element) {
+	gboolean retvalue = FALSE;
 	JammoTrackClass* track_class;
 
 	track_class = JAMMO_TRACK_GET_CLASS(track);
-	if (track_class->get_element) {
-		element = track_class->get_element(track);
+	if (track_class->setup_element) {
+		retvalue = track_class->setup_element(track, bin, sink_element);
 	}
-
-	return element;
+	
+	return retvalue;
 }
 
 /**
@@ -86,13 +86,49 @@ GstElement* _jammo_track_get_element(JammoTrack* track) {
  *
  * Internally called by a #JammoSequencer when it receives
  * a new message.
+ *
+ * Return value: TRUE, if the message is handled, or FALSE if the message must be delivered to the next track in a line
  */
-void _jammo_track_receive_message(JammoTrack* track, GstMessage* message) {
+gboolean _jammo_track_receive_message(JammoTrack* track, GstMessage* message) {
+	gboolean retvalue = FALSE;
 	JammoTrackClass* track_class;
 
 	track_class = JAMMO_TRACK_GET_CLASS(track);
 	if (track_class->receive_message) {
-		track_class->receive_message(track, message);
+		retvalue = track_class->receive_message(track, message);
+	}
+	
+	return retvalue;
+}
+
+void _jammo_track_set_tempo(JammoTrack* track, guint tempo) {
+	JammoTrackClass* track_class;
+
+	track_class = JAMMO_TRACK_GET_CLASS(track);
+	if (track_class->set_tempo) {
+		track_class->set_tempo(track, tempo);
+	} else {
+		g_warning("Virtual function set_tempo() is not implemented in %s.", G_OBJECT_TYPE_NAME(G_OBJECT(track)));
+	}
+}
+
+void _jammo_track_set_pitch(JammoTrack* track, const gchar* pitch) {
+	JammoTrackClass* track_class;
+
+	track_class = JAMMO_TRACK_GET_CLASS(track);
+	if (track_class->set_pitch) {
+		track_class->set_pitch(track, pitch);
+	} else {
+		g_warning("Virtual function set_pitch() is not implemented in %s.", G_OBJECT_TYPE_NAME(G_OBJECT(track)));
+	}
+}
+
+void _jammo_track_set_offline(JammoTrack* track, gboolean offline) {
+	JammoTrackClass* track_class;
+
+	track_class = JAMMO_TRACK_GET_CLASS(track);
+	if (track_class->set_offline) {
+		track_class->set_offline(track, offline);
 	}
 }
 
@@ -115,7 +151,7 @@ static void jammo_track_class_init(JammoTrackClass* track_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(track_class);
 
 	gobject_class->get_property = jammo_track_get_property;
-
+	
 	/**
 	 * JammoTrack:duration:
 	 *
