@@ -59,8 +59,9 @@ int main (int argc, char **argv) {
 
 // ******** Start **********************************************************
 
-	printf("starting\n");
-	jammo_collaboration_group_composition_start(collaboration_group_composition);
+	// can not start. it requires gems
+	//printf("starting\n");
+	//jammo_collaboration_group_composition_start(collaboration_group_composition);
 
 	printf("calling jammo_collaboration_game_teacher_exit\n");
 	jammo_collaboration_game_teacher_exit(JAMMO_COLLABORATION_GAME(collaboration_group_composition));
