@@ -8,9 +8,19 @@
  * Authors: Henrik Hedberg <henrik.hedberg@oulu.fi>
  */
 
+#include <meam/jammo-meam.h>
 #include <chum/jammo-chum.h>
 #include <chum/jammo-mentor.h>
 
+static gboolean activate_mentor(gpointer user_data) {
+	JammoMentor* mentor;
+	
+	mentor = JAMMO_MENTOR(user_data);
+	jammo_mentor_speak_and_highlight(mentor, "test_sound.wav", 100.0, -10.0);
+
+	return FALSE;
+}
+
 int main(int argc, char** argv) {
 	ClutterActor* stage;
 	ClutterActor* texture;
@@ -31,6 +41,8 @@ int main(int argc, char** argv) {
 	
 	clutter_container_add_actor(CLUTTER_CONTAINER(stage), mentor);
 	
+	g_timeout_add(5000, activate_mentor, mentor);
+	
 	clutter_actor_show_all(stage);
 	clutter_main();
 	
