@@ -69,6 +69,8 @@ int main(int argc, char** argv) {
 	main_loop = g_main_loop_new (NULL, FALSE);
 
 	sequencer = jammo_sequencer_new();
+	jammo_sequencer_set_pitch(sequencer, "F#");
+	jammo_sequencer_set_tempo(sequencer, 90);
 	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), main_loop);
 
 	track1 = jammo_editing_track_new();
@@ -87,13 +89,16 @@ int main(int argc, char** argv) {
 	sample2 = jammo_sample_new_from_file("/tmp/sample2.wav");
 	jammo_editing_track_add_sample(track2, sample2, 5000000000LL);
 	sample3 = jammo_sample_new_from_file("/tmp/sample3.wav");
-	jammo_editing_track_add_sample(track2, sample3, 2000000000LL);
+	jammo_editing_track_add_sample(track2, sample3, 0);
 
-	jammo_playing_track_set_echo_delay(JAMMO_PLAYING_TRACK(track2), 1500000);
-	jammo_playing_track_set_echo_intensity(JAMMO_PLAYING_TRACK(track2), 1.0);
+	jammo_playing_track_set_echo_delay(JAMMO_PLAYING_TRACK(track2), 175000000);
+	jammo_playing_track_set_echo_intensity(JAMMO_PLAYING_TRACK(track2), 0.4);
 	jammo_playing_track_set_echo_feedback(JAMMO_PLAYING_TRACK(track2), 0.5);
 
-	jammo_sequencer_play((JammoSequencer*)sequencer);
+	jammo_playing_track_set_panning_enabled(JAMMO_PLAYING_TRACK(track1), TRUE);
+	jammo_playing_track_set_panning_enabled(JAMMO_PLAYING_TRACK(track2), TRUE);
+
+	jammo_sequencer_play(JAMMO_SEQUENCER(sequencer));
 
 	g_timeout_add(150, do_panning, track1);
 	g_timeout_add(50, do_panning, track2);
